Learn R Programming

fastliu (version 1.0)

print.statliu: Print Method for Liu Regression Statistics

Description

statliu computes the statistics related to the Liu regression.

Usage

# S3 method for statliu
print(x, digits = 5, ...)

Value

The return object is the statistics relatec to the Liu regression.

Arguments

x

A statliu object

digits

Number of decimal places in the data frame of Liu regression statistics.

...

Other parameters related to print.

Author

Murat Genç

See Also

liureg(), summary(), pressliu(), residuals()

Examples

Run this code
Hitters <- na.omit(Hitters)
X <- model.matrix(Salary ~ ., Hitters)[, -1]
y <- Hitters$Salary
lam <- seq(0, 1, 0.01)
liu.mod <- liureg(X, y, lam)
stats <- statliu(liu.mod)
print(stats)

Run the code above in your browser using DataLab