For each value of the regularization parameter lambda,
diagHliu returns the diagonal elements of the hat matrix.
Unlike the hatliu function, only the diagonal
elements of the hat matrix are calculated, thus the
computation of diagonal elements is faster than hatliu.
Usage
diagHliu(obj)
Value
The returned object is a matrix whose columns are the
diagonal elements of the hat matrix for each value of the
lambda regularization parameter.