Learn R Programming

fastliu (version 1.0)

pressliu: Predicted Residual Sum of Squares (PRESS)

Description

pressliu computes the predicted residual sum of squares (PRESS) based on a Liu regression model.

Usage

pressliu(obj, digits = 5L, ...)

Value

The returned object is a vector of PRESS values computed for each lambda..

Arguments

obj

A liureg object.

digits

Decimal places in the columns of data frame of PRESS values. Can be an integer of vector of integers.

...

Not used in this implementation.

Author

Murat Genç, Ömer Özbilen

Details

The PRESS statistic is based on the predicted leave-one-out residual sum of squares. The statistic is computed as \({\sum\limits _{i=1}^{n}\left(\frac{\hat{e}_{\lambda i}}{1-h_{1-ii}}-\frac{e_{i}\left(h_{1-ii}-\tilde{\mathbf{H}}_{\lambda-ii}\right)}{\left(1-h_{1-ii}\right)\left(1-h_{ii}\right)}\right)^{2}}\) where \(h_{ii}\) is the \(i\)th diagonal element of the hat matrix corresponding to the least squares estimator, \(h_{1-ii}\) is the \(i\)th diagonal element of the hat matrix of the Liu estimator and \(e_{\lambda i}\) is the residual at the specific value of \(\lambda\).

References

Liu, K. (1993). A new class of blased estimate in linear regression. Communications in Statistics-Theory and Methods, 22(2), 393-402. tools:::Rd_expr_doi("10.1080/03610929308831027").

Ozkale, M. R. and Kaciranlar, S. (2007). A prediction-oriented criterion for choosing the biasing parameter in Liu estimation. Communications in Statistics-Theory and Methods, 36(10), 1889-1903. tools:::Rd_expr_doi("10.1080/03610920601126522").

See Also

liureg(), pressliu(), residuals()

Examples

Run this code
data("Hitters")
Hitters <- na.omit(Hitters)
X <- model.matrix(Salary ~ ., Hitters)[, -1]
y <- Hitters$Salary
lam <- seq(0, 1, 0.01)
liu.mod <- liureg(X, y, lam)
pressliu(liu.mod)

Run the code above in your browser using DataLab