powered by
statliu computes the statistics related to the Liu regression.
statliu
# S3 method for statliu print(x, digits = 5, ...)
The return object is the statistics relatec to the Liu regression.
A statliu object
Number of decimal places in the data frame of Liu regression statistics.
Other parameters related to print.
print
Murat Genç
liureg(), summary(), pressliu(), residuals()
liureg()
summary()
pressliu()
residuals()
Hitters <- na.omit(Hitters) X <- model.matrix(Salary ~ ., Hitters)[, -1] y <- Hitters$Salary lam <- seq(0, 1, 0.01) liu.mod <- liureg(X, y, lam) stats <- statliu(liu.mod) print(stats)
Run the code above in your browser using DataLab