# S3 method for liureg
summary(object, digits, ...)
Value
The returned object is a list whose elements are Liu
regression coefficient estimates and statistics related to Liu regression.
Arguments
object
An object of class liureg.
digits
Number of decimal places in the data frame of Liu regression statistics.
...
Not used in this implemetation.
Author
Murat Genç
Details
summary.liureg produces an object with S3 class summary.liureg.
The function returns a list of summary statistics of the Liu regression fit for the grid
of regularization parameter \(\lambda\) values. Each element of the output list includes:
coefficients
A \(p\times 5\) matrix with columns coefficient estimates,
scaled coefficient estimates, scaled standard errors, scaled \(t-\)values with corresponding
\(p-\)value.
Statistics
Liu related statistics \(R^2\), \(\textrm{adjusted}-R^2\),
\(F-\)statistics, AIC, BIC and MSE values.